==> qmmp_1.2.0.orig.tar.bz2: qmmp-1.2.0/src/plugins/General/notifier/translations/notifier_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Modulo notifica</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>Info sul modulo notifica</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Modulo notifica per Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autore: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="116"/>
        <source>Volume:</source>
        <translation>Volume:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="388"/>
        <source>Psi Notification</source>
        <translation>Notifica Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="400"/>
        <source>Enable Psi notification</source>
        <translation>Abilita notifica Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Notifica sul desktop</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>Ritardo (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Transparency:</source>
        <translation>Trasparenza:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="251"/>
        <source>Edit template</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="375"/>
        <source>Disable notifications when another application is in the Full Screen Mode</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="378"/>
        <source>Disable for full screen windows</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Impostazioni modulo notifica</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>Notifica cambio brano</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>Notifica modifica volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>Notification Template</source>
        <translation>Modello di notificazione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Font:</source>
        <translation>Carattere;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>Dimensione copertina:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>...</source>
        <translation>...</translation>
    </message>
</context>
</TS>

==> qmmp-1.2.3.tar.bz2: qmmp-1.2.3/src/plugins/General/notifier/translations/notifier_plugin_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="it">
<context>
    <name>NotifierFactory</name>
    <message>
        <location filename="../notifierfactory.cpp" line="30"/>
        <source>Notifier Plugin</source>
        <translation>Estensione notifica</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="50"/>
        <source>About Notifier Plugin</source>
        <translation>Informazioni sull&apos;estensione notifica</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="51"/>
        <source>Qmmp Notifier Plugin</source>
        <translation>Estensione notifica per Qmmp</translation>
    </message>
    <message>
        <location filename="../notifierfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Autori: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>PopupWidget</name>
    <message>
        <location filename="../popupwidget.cpp" line="116"/>
        <source>Volume:</source>
        <translation>Volume:</translation>
    </message>
</context>
<context>
    <name>SettingsDialog</name>
    <message>
        <location filename="../settingsdialog.ui" line="14"/>
        <source>Notifier Plugin Settings</source>
        <translation>Impostazioni estensione notifica</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="35"/>
        <source>Desktop Notification</source>
        <translation>Notifica sul desktop</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="51"/>
        <source>Font:</source>
        <translation>Carattere;</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="71"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="78"/>
        <location filename="../settingsdialog.ui" line="279"/>
        <source>0</source>
        <translation>0</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="85"/>
        <source>Transparency:</source>
        <translation>Trasparenza:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="229"/>
        <source>Position</source>
        <translation>Posizione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="251"/>
        <source>Edit template</source>
        <translation>Modifica modello</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="299"/>
        <source>Cover size:</source>
        <translation>Dimensione copertina:</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="325"/>
        <source>Volume change notification</source>
        <translation>Notifica di modifica volume</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="332"/>
        <source>Delay (ms):</source>
        <translation>Ritardo (ms):</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="361"/>
        <source>Playback resume notification</source>
        <translation>Notifica di ripresa della riproduzione</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="368"/>
        <source>Song change notification</source>
        <translation>Notifica di cambio brano</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="375"/>
        <source>Disable notifications when another application is in the Full Screen Mode</source>
        <translation>Disabilita le notifiche quando un&apos;altra applicazione è in modalità a schermo intero</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="378"/>
        <source>Disable for full screen windows</source>
        <translation>Disabilita per finestre a schermo intero</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="388"/>
        <source>Psi Notification</source>
        <translation>Notifica Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.ui" line="400"/>
        <source>Enable Psi notification</source>
        <translation>Abilita notifica Psi</translation>
    </message>
    <message>
        <location filename="../settingsdialog.cpp" line="109"/>
        <source>Notification Template</source>
        <translation>Modello di notifica</translation>
    </message>
</context>
</TS>
